pub struct ComputeConstraint {
pub min: Option<ComputeResource>,
}Fields
min: Option<ComputeResource>Trait Implementations
Sourceimpl Clone for ComputeConstraint
impl Clone for ComputeConstraint
Sourcefn clone(&self) -> ComputeConstraint
fn clone(&self) -> ComputeConstraint
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ComputeConstraint
impl Debug for ComputeConstraint
Sourceimpl<'de> Deserialize<'de> for ComputeConstraint
impl<'de> Deserialize<'de> for ComputeConstraint
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ComputeConstraint
impl JsonSchema for ComputeConstraint
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ComputeConstraint
impl PartialEq for ComputeConstraint
Sourceimpl Serialize for ComputeConstraint
impl Serialize for ComputeConstraint
Sourceimpl<'__s> ToSchema<'__s> for ComputeConstraint
impl<'__s> ToSchema<'__s> for ComputeConstraint
impl StructuralPartialEq for ComputeConstraint