pub struct ComputeResource {
pub cpu: Option<String>,
pub memory: Option<String>,
}Fields
cpu: Option<String>memory: Option<String>Trait Implementations
Sourceimpl Clone for ComputeResource
impl Clone for ComputeResource
Sourcefn clone(&self) -> ComputeResource
fn clone(&self) -> ComputeResource
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ComputeResource
impl Debug for ComputeResource
Sourceimpl<'de> Deserialize<'de> for ComputeResource
impl<'de> Deserialize<'de> for ComputeResource
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ComputeResource
impl JsonSchema for ComputeResource
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ComputeResource
impl PartialEq for ComputeResource
Sourceimpl Serialize for ComputeResource
impl Serialize for ComputeResource
Sourceimpl<'__s> ToSchema<'__s> for ComputeResource
impl<'__s> ToSchema<'__s> for ComputeResource
impl StructuralPartialEq for ComputeResource