pub struct Infrastructure {
pub cpu: String,
pub memory: String,
pub storage: String,
}Fields
cpu: Stringmemory: Stringstorage: StringTrait Implementations
Sourceimpl Clone for Infrastructure
impl Clone for Infrastructure
Sourcefn clone(&self) -> Infrastructure
fn clone(&self) -> Infrastructure
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Infrastructure
impl Debug for Infrastructure
Sourceimpl Default for Infrastructure
impl Default for Infrastructure
Sourcefn default() -> Infrastructure
fn default() -> Infrastructure
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for Infrastructure
impl<'de> Deserialize<'de> for Infrastructure
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Infrastructure
impl JsonSchema for Infrastructure
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for Infrastructure
impl PartialEq for Infrastructure
Sourceimpl Serialize for Infrastructure
impl Serialize for Infrastructure
Sourceimpl<'__s> ToSchema<'__s> for Infrastructure
impl<'__s> ToSchema<'__s> for Infrastructure
impl StructuralPartialEq for Infrastructure