pub struct Stack {Show 14 fields
pub name: String,
pub compute_constraints: Option<ComputeConstraint>,
pub description: Option<String>,
pub organization: String,
pub repository: String,
pub images: ImagePerPgVersion,
pub stack_version: Option<String>,
pub trunk_installs: Option<Vec<TrunkInstall>>,
pub extensions: Option<Vec<Extension>>,
pub postgres_metrics: Option<QueryConfig>,
pub postgres_config: Option<Vec<PgConfig>>,
pub postgres_config_engine: Option<ConfigEngine>,
pub infrastructure: Option<Infrastructure>,
pub app_services: Option<Vec<AppService>>,
}Fields
name: Stringcompute_constraints: Option<ComputeConstraint>specifies any resource constraints that should be applied to an instance of the Stack
description: Option<String>organization: StringOrganization hosting the Docker images used in this stack Default: “tembo”
repository: Stringimages: ImagePerPgVersionThe Docker images to use for each supported Postgres versions
Default: 14: “standard-cnpg:14-bffd097” 15: “standard-cnpg:15-bffd097” 16: “standard-cnpg:16-bffd097” 17: “standard-cnpg:17-bffd097”
stack_version: Option<String>trunk_installs: Option<Vec<TrunkInstall>>extensions: Option<Vec<Extension>>postgres_metrics: Option<QueryConfig>Postgres metric definition specific to the Stack
postgres_config: Option<Vec<PgConfig>>configs are strongly typed so that they can be programmatically transformed
postgres_config_engine: Option<ConfigEngine>infrastructure: Option<Infrastructure>external application services
app_services: Option<Vec<AppService>>Implementations